"A very simple short module containing useful functions"


What's new in version 1.6.1-> Corrected some color values

What's new in version 1.7.1-> Added transform_color function and updated documentation.

What's new in version 1.7.2-> Fixed shutil module import error

What's new in version 1.8.0-> Changed remove_dir(...) function to delete(...).

What's new in version 1.8.1-> Fixed is_Folder(...) function, and added is_File(path) function.

What's new in version 1.8.2-> Fixed get_foldername(...) and get_filename(...).

What's new in version 1.9.0-> Fixed get_startup_path(...) function

What's new in version 1.9.2-> Removed some unecessary print staements

What's new in version 1.9.2-> Fixed some bugs

What's new in version 1.9.3-> Added convert_currency function, which works on forex_python module

What's new in version 1.9.4-> Fixed some bugs

What's new in version 1.9.5-> Fixed some bugs

What's new in version 2.0.0-> Squashed major bugs, which stopped any python script from being 
converted to .exe file in pyinstaller, py2exe and cx_Freeze.

What's new in version 2.1.0-> Added functions encrypt(...) and decrypt(...) for easy AES-256 enc/decryption.
Also, the documentation of some functions have been changed, including email(...) and delete(...)

What's new in version 2.1.1-> Added new functions encrypt(...) and decrypt(...) and changed the
name of the older functions from encrypt(...) and decrypt(...) to encryptFile(...) and decryptFile(...).
New enc/decrypt(...) functions are used only for strings. enc/decryptFile(...) functions are
used only for Files.

What's new in version 2.1.3-> Added HTML email functationality in email(...) funtion.

What's new in version 2.1.4-> Fixed HTML email functionality bug where pictures won't show 
in the email, but the HTML content does show up.

What's new in version 2.2.1-> Added make_hash(...) and pinput(...) functions

What's new in version 2.2.8-> Removed bugs

What's new in version 2.3.0-> Added compress(...) and extract(...) functions

What's new in version 2.4.1-> Completely changed the pinput(...) functions due to some bugs in it.

What's new in version 2.5.0-> Added tj module branding in encrypted files
